%ifarch %ix86
%define p4arch x86
%define md5sum f9d76ae94b8a6b1deff78241b8bb643c
%endif

%ifarch x86_64
%define p4arch x86_64
%define md5sum 5a576239474bf06ffd0be19365150b39
%endif

# on version update, update:
# - manifest (SOURCE0)
# - files section
# - bin symlinks
# - md5sums
%define version 12.3
%define revision 578478
%define rel 4

%define tarname	%{name}.tgz
%define downurl http://www.perforce.com/downloads/perforce/r%{version}/bin.linux26%{p4arch}/%{tarname}
%define downfile %{_localstatedir}/lib/%{name}/%{tarname}
%define distname %{name}-20%{version}.%{revision}
%define EULAurl http://www.perforce.com/perforce/contracts/subscriptionEULA.pdf
%define installdir %{_libdir}/%{name}

Summary:	Perforce Visual Client
Name:		p4v
Version:	%{version}
Release:	%mkrel %{rel}
# list of files to be installed
# <perms> <file>
Source0:	manifest.txt
License:	Proprietary
URL:		http://www.perforce.com/product/perforce
Group:		Development/Other
ExclusiveArch:	%ix86 x86_64
Requires(pre):	curl
Recommends:	p4
# helper for getting requires:
# for i in $(objdump -p /usr/lib64/p4v/bin/p4v.bin | grep NEEDED | awk '{ print $2 }' | grep -v ld-linux); do echo -e "Requires: \x25arch_tagged $i"; done
#Requires: %arch_tagged libfreetype.so.6

# FIXME: use system qt4 libs instead of p4v internal copies

%description
P4V, the Perforce Visual Client, provides quick and easy access to
versioned files through a graphical interface.

NOTE: This package does not contain %{name} itself. The
software will be automatically downloaded during package
installation.

Installing this package indicates acceptance of the %{name} EULA,
available at %{EULAurl}.

%prep
%setup -c -T

%install

install -d -m755 %{buildroot}%{_datadir}/%{name}
install -m644 %{SOURCE0} %{buildroot}%{_datadir}/%{name}/manifest.txt

install -d -m755 %{buildroot}%{_localstatedir}/lib/%{name}
install -d -m755 %{buildroot}%{installdir}

while read mode file; do
  install -d -m755 %{buildroot}%{installdir}/$(dirname ${file})
  touch %{buildroot}%{installdir}/${file}
done < %{SOURCE0}

# symlinks binaries in bindir, but do not symlink "assistant"
bins="p4admin p4merge p4sandbox p4sandbox-config p4sandbox-p4d p4v p4vc"
install -d -m755 %{buildroot}%{_bindir}
for bin in ${bins}; do
  ln -s %{installdir}/bin/${bin} %{buildroot}%{_bindir}/${bin}
done

%pre
get_proxy_from_urpmi() {
	if [ -e /etc/urpmi/proxy.cfg ]; then
		proxy="$(grep ^http_proxy= /etc/urpmi/proxy.cfg 2>/dev/null)"
		proxy_user="$(grep ^proxy_user= /etc/urpmi/proxy.cfg 2>/dev/null)"

		proxy="${proxy#http_proxy=}"
		proxy_user="${proxy_user#proxy_user=}"

		[ -n "$proxy" ] && echo "--proxy $proxy"
		[ -n "$proxy_user" ] && echo "--proxy-user $proxy_user"
	fi
}

echo "Note that by downloading %{name} you indicate your acceptance of the EULA,"
echo "available at %{EULAurl}"

echo "Downloading from %{downurl}"
install -d -m755 $(dirname %{downfile})
curl --connect-timeout 20 -m 10800 -L $(get_proxy_from_urpmi) "%{downurl}" > "%{downfile}"

if ! [ -f %{downfile} ]; then
   echo "Download failed"
   exit 1
fi

md5chk=$(md5sum %{downfile} | cut -d' ' -f1)
if ! [ "%{md5sum}" = "$md5chk" ]; then
   echo "Download checksum failed"
   rm -f %{downfile}
   exit 1
fi

%post
set -e 
tmp_extract_dir=$(mktemp -d)

if ! [ -d ${tmp_extract_dir} ]; then
  echo "Failed to create temporary directory for %{name}"
  rm -f %{downfile} 
  exit 1
fi

tar xa -C ${tmp_extract_dir} -f %{downfile}

if ! [ -d ${tmp_extract_dir}/%{distname} ]; then
  echo "Extracted folder %{distname} missing"
  rm -rf ${tmp_extract_dir} %{downfile}
  exit 1
fi

while read mode file; do
  install -d -m755 %{installdir}/$(dirname ${file})
  mv ${tmp_extract_dir}/%{distname}/${file} %{installdir}/${file}
  chmod ${mode} %{installdir}/${file}
done < %{_datadir}/%{name}/manifest.txt

unpackaged_files=$(find ${tmp_extract_dir} -type f)
if [ -n "${unpackaged_files}" ]; then
   echo "%{name} install: WARNING, some files have not been installed: ${unpackaged_files}"
fi
rm -rf ${tmp_extract_dir} %{downfile}

echo "%{name} installation successful."

%files
%dir   %{_datadir}/%{name}
%{_datadir}/%{name}/manifest.txt
%{_bindir}/p4admin
%{_bindir}/p4merge
%{_bindir}/p4sandbox
%{_bindir}/p4sandbox-config
%{_bindir}/p4sandbox-p4d
%{_bindir}/p4v
%{_bindir}/p4vc
%dir   %{_localstatedir}/lib/%{name}
%dir   %{installdir}
%dir   %{installdir}/bin
%ghost %{installdir}/bin/assistant
%ghost %{installdir}/bin/p4admin
%ghost %{installdir}/bin/p4admin.bin
%ghost %{installdir}/bin/p4merge
%ghost %{installdir}/bin/p4merge.bin
%ghost %{installdir}/bin/p4sandbox
%ghost %{installdir}/bin/p4sandbox-config
%ghost %{installdir}/bin/p4sandbox-config.bin
%ghost %{installdir}/bin/p4sandbox-p4d
%ghost %{installdir}/bin/p4v
%ghost %{installdir}/bin/p4v.bin
%ghost %{installdir}/bin/p4vc
%ghost %{installdir}/bin/qt.conf
%dir   %{installdir}/lib
%dir   %{installdir}/lib/%{name}
%dir   %{installdir}/lib/%{name}/P4VResources
%ghost %{installdir}/lib/%{name}/P4VResources/images.rcc
%dir   %{installdir}/lib/%{name}/P4VResources/p4adminhelp
%ghost %{installdir}/lib/%{name}/P4VResources/p4adminhelp/*.qch
%ghost %{installdir}/lib/%{name}/P4VResources/p4adminhelp/*.qhc
%dir   %{installdir}/lib/%{name}/P4VResources/p4mergehelp
%ghost %{installdir}/lib/%{name}/P4VResources/p4mergehelp/*.qch
%ghost %{installdir}/lib/%{name}/P4VResources/p4mergehelp/*.qhc
%dir   %{installdir}/lib/%{name}/P4VResources/p4vhelp
%ghost %{installdir}/lib/%{name}/P4VResources/p4vhelp/*.qch
%ghost %{installdir}/lib/%{name}/P4VResources/p4vhelp/*.qhc
%ghost %{installdir}/lib/%{name}/P4VResources/p4vhelp/*.pdf
%dir   %{installdir}/lib/%{name}/P4VResources/examples
%ghost %{installdir}/lib/%{name}/P4VResources/examples/*.xml
%dir   %{installdir}/lib/%{name}/P4VResources/icons
%ghost %{installdir}/lib/%{name}/P4VResources/icons/*.png
%dir   %{installdir}/lib/%{name}/P4VResources/translations
%ghost %{installdir}/lib/%{name}/P4VResources/translations/*.qm
%dir   %{installdir}/lib/%{name}/qt4
%dir   %{installdir}/lib/%{name}/qt4/lib
%ghost %{installdir}/lib/%{name}/qt4/lib/*.so.*
%dir   %{installdir}/lib/%{name}/qt4/plugins
%dir   %{installdir}/lib/%{name}/qt4/plugins/accessible
%ghost %{installdir}/lib/%{name}/qt4/plugins/accessible/*.so
%dir   %{installdir}/lib/%{name}/qt4/plugins/codecs
%ghost %{installdir}/lib/%{name}/qt4/plugins/codecs/*.so
%dir   %{installdir}/lib/%{name}/qt4/plugins/imageformats
%ghost %{installdir}/lib/%{name}/qt4/plugins/imageformats/*.so
%dir   %{installdir}/lib/%{name}/qt4/plugins/sqldrivers
%ghost %{installdir}/lib/%{name}/qt4/plugins/sqldrivers/*.so


%changelog
* Fri Jul 07 2017 akien <akien> 12.3-4.mga6
+ Revision: 1109204
- Mageia 6 rebuild

* Wed Oct 15 2014 umeabot <umeabot> 12.3-3.mga5.nonfree
+ Revision: 745373
- Second Mageia 5 Mass Rebuild

* Mon Sep 15 2014 tv <tv> 12.3-2.mga5.nonfree
+ Revision: 676096
- s/uggests:/Recommends:/

* Thu Oct 31 2013 tmb <tmb> 12.3-2.mga4.nonfree
+ Revision: 548463
- Mageia 4 rebuild

* Sun Mar 03 2013 blino <blino> 12.3-1.mga3.nonfree
+ Revision: 401312
- suggest p4
- initial package
- Created package structure for p4v.

